package meerkat.voting;

import com.google.common.util.concurrent.FutureCallback;
import meerkat.protobuf.Voting.*;

/**
 * An interface for the device in which we output the ballots.
 * Probably going to be a printer or an ethernet connection, or both.
 */
public interface BallotOutputDevice {

    /**
     * Output the encrypted ballot. This is a commitment before voter chooses casting or auditing
     * @param encryptedBallot - the encrypted ballot to commit to
     * @param callback - a callback object through which to return a success flag
     */
    public void commitToBallot(EncryptedBallot encryptedBallot, FutureCallback<Boolean> callback);

    /**
     * Voter chose 'audit'. Output the ballot secrets to prove correctness of the encryption.
     * @param encryptedBallot - the encrypted ballot
     * @param ballotSecrets - the secrtes of the encryption
     * @param callback - a callback object through which to return a success flag
     */
    public void audit(EncryptedBallot encryptedBallot, BallotSecrets ballotSecrets, FutureCallback<Boolean> callback);

    /**
     * Voter chose 'cast'. Finalize the ballot for use in the polling station
     * @param callback - a callback object through which to return a success flag
     */
    public void castBallot(FutureCallback<Boolean> callback);

    /**
     * Cancelling the current ballot. This clears the state of the OutputDevice if the implementation has any such state.
     * @param callback - a callback object through which to return a success flag
     */
    public void cancelBallot(FutureCallback<Boolean> callback);

}
