package meerkat.voting;

import meerkat.protobuf.Voting.*;

/**
 * An interface for the controller component of the voting booth
 */
public interface VotingBooth {

    /**
     * initialize using the BoothParams protobuf and sett all the different components of the Voting Booth to be recognized by this controller
     * @param boothParams
     * @param outputDevice the ballot output device. Naturally a printer and/or ethernet connection
     * @param vbEncryptor the encryption module
     * @param vbUI User interface in which the voter chooses his answers
     * @param vbStorageManager storage component for handling files and USB sticks
     */
    public void init (BoothParams boothParams,
                      BallotOutputDevice outputDevice,
                      VotingBoothEncryptor vbEncryptor,
                      VotingBoothUI vbUI,
                      StorageManager vbStorageManager);

    /**
     * set the voting questions
     * @param questions
     */
    public void setBallotQuestions (BallotQuestion[] questions);

    /**
     * a synchronous function. Starts running the controller component, and basically run the whole system for voting
     */
    public void run ();

    /**
     * an asynchronous call from Admin Console (If there is such one implemented) to shut down the system
     */
    public void shutDown();

}
